/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.kommentar;

import java.time.ZonedDateTime;
import java.util.stream.Stream;

import jakarta.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import de.ozgcloud.alfa.common.attacheditem.VorgangAttachedItemService;
import de.ozgcloud.alfa.common.command.Command;
import de.ozgcloud.alfa.common.user.CurrentUserService;

@Validated
@Service
class KommentarService {

	@Autowired
	private KommentarRemoteService remoteService;
	@Autowired
	private CurrentUserService currentUserService;
	@Autowired
	private VorgangAttachedItemService vorgangAttachedItemService;

	public Command createKommentar(@Valid Kommentar kommentar, String vorgangId) {
		return vorgangAttachedItemService.createNewKommentar(addCreated(kommentar), vorgangId);
	}

	Kommentar addCreated(Kommentar kommentar) {
		return kommentar.toBuilder()
				.createdAt(ZonedDateTime.now().withNano(0))
				.createdBy(currentUserService.getUserId().toString())
				.build();
	}

	public Command editKommentar(@Valid Kommentar kommentar, String kommentarId, long kommentarVersion) {
		var loadedKommentar = getById(kommentarId);
		var preparedKommentar = loadedKommentar.toBuilder()
				.text(kommentar.getText())
				.clearAttachments().attachments(kommentar.getAttachments())
				.build();

		return vorgangAttachedItemService.editKommentar(preparedKommentar, kommentarId, kommentarVersion);
	}

	public Stream<Kommentar> findByVorgangId(String vorgangId) {
		return remoteService.findByVorgangId(vorgangId);
	}

	public Kommentar getById(String kommentarId) {
		return remoteService.getById(kommentarId);
	}
}