/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.collaboration;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.UUID;
import java.util.stream.Stream;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

class CollaborationServiceTest {

	@InjectMocks
	private CollaborationService service;

	@Mock
	private CollaborationRemoteService remoteService;

	@Nested
	class TestGetById {

		public static final String COLLABORATION_ID = FachstelleCollaborationTestFactory.ID;

		@Test
		void shouldCallRemoteService() {
			service.getById(COLLABORATION_ID);

			verify(remoteService).getById(COLLABORATION_ID);
		}

		@Test
		void shouldReturnCollaboration() {
			var expected = FachstelleCollaborationTestFactory.create();
			when(remoteService.getById(COLLABORATION_ID)).thenReturn(expected);

			var collaboration = service.getById(COLLABORATION_ID);

			assertThat(collaboration).isEqualTo(expected);
		}
	}

	@Nested
	class TestGetCollaborations {

		private static final String VORGANG_ID = UUID.randomUUID().toString();

		@Test
		void shouldCallRemoteService() {
			callService();

			verify(remoteService).getCollaborations(VORGANG_ID);
		}

		@Test
		void shouldReturnCollaboration() {
			var collaboration = FachstelleCollaborationTestFactory.create();
			when(remoteService.getCollaborations(VORGANG_ID)).thenReturn(Stream.of(collaboration));

			var returnedCollaboration = callService();

			assertThat(returnedCollaboration).contains(collaboration);
		}

		private Stream<Collaboration> callService() {
			return service.getCollaborations(VORGANG_ID);
		}
	}

	@Nested
	class TestHasCollaboration {

		private final String id = UUID.randomUUID().toString();

		@Test
		void shouldCallRemoteService() {
			callService();

			verify(remoteService).getCollaborations(id);
		}

		@Test
		void shouldReturnTrue() {
			var collaboration = FachstelleCollaborationTestFactory.create();
			when(remoteService.getCollaborations(id)).thenReturn(Stream.of(collaboration));

			var hasCollaboration = callService();

			assertThat(hasCollaboration).isTrue();
		}

		@Test
		void shouldReturnFalse() {
			when(remoteService.getCollaborations(id)).thenReturn(Stream.empty());

			var hasCollaboration = callService();

			assertThat(hasCollaboration).isFalse();
		}

		private boolean callService() {
			return service.hasCollaboration(id);
		}
	}
}
