/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.List;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;

class LinkedResourceCollectionProcessorTest {

	@InjectMocks
	private LinkedResourceCollectionProcessor<TestEntity> processor;
	@Mock
	private LinkedResourceProcessor<TestEntity> elementProcessor;

	@Nested
	class TestProcess {

		@Test
		void shouldReturnSameCollectionModel() {
			var collectionModel = CollectionModel.of(List.of(EntityModel.of(TestEntityTestFactory.create())));

			var result = processor.process(collectionModel);

			assertThat(collectionModel).isSameAs(result);
		}

		@Test
		void shouldCallLinkedResourceProcessor() {
			var entityModel = EntityModel.of(TestEntityTestFactory.create());
			var collectionModel = CollectionModel.of(List.of(entityModel));

			processor.process(collectionModel);

			verify(elementProcessor).process(entityModel);
		}
	}
}
