/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.user;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class CurrentUserHelperTest {

	@DisplayName("Prepare role for check")
	@Nested
	class TestPrepareRoleForCheck {

		@Test
		void shouldAddPrefixIfMissing() {
			var roleWithoutPrefix = UserRole.VERWALTUNG_USER;

			var role = CurrentUserHelper.prepareRoleForCheck(roleWithoutPrefix);

			assertThat(role).isEqualTo(String.format("%s%s", CurrentUserHelper.ROLE_PREFIX, UserRole.VERWALTUNG_USER));
		}

		@Test
		void shouldReturnRoleIfPrefixAlreadyExists() {
			var roleWithPrefix = String.format("ROLE_%s", UserRole.VERWALTUNG_USER);

			var role = CurrentUserHelper.prepareRoleForCheck(roleWithPrefix);

			assertThat(role).isEqualTo(roleWithPrefix);
		}

		@Test
		void shouldReturnPassingRoleIfNonNull() {
			var role = CurrentUserHelper.prepareRoleForCheck(null);

			assertThat(role).isNull();
		}
	}
}
