/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.kommentar;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.Link;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.alfa.common.LinkedResourceProcessor;
import de.ozgcloud.alfa.common.user.UserManagerUrlProvider;

class KommentarLinkedResourceTest {

	@InjectMocks
	private LinkedResourceProcessor<Kommentar> processor;
	@Mock
	private UserManagerUrlProvider userManagerUrlProvider;

	@Nested
	class TestEntityModelProcessing {
		private static final String REL_CREATED_BY = "createdBy";
		private static final String USER_MANAGER_URL = LoremIpsum.getInstance().getUrl();

		@Test
		void shouldHaveCreatedByLink() {
			when(userManagerUrlProvider.getUserProfileTemplate()).thenReturn(USER_MANAGER_URL + "%s");

			var model = processor.process(EntityModel.of(KommentarTestFactory.create()));

			assertThat(model.getLink(REL_CREATED_BY)).isPresent().get().extracting(Link::getHref)
					.isEqualTo(USER_MANAGER_URL + KommentarTestFactory.CREATED_BY);
		}
	}
}
