/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Spy;

import de.ozgcloud.alfa.postfach.GrpcPostfachAddressTestFactory;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;

class ServiceKontoMapperTest {

	@InjectMocks
	private ServiceKontoMapper mapper = Mappers.getMapper(ServiceKontoMapper.class);
	@Spy
	private GrpcObjectMapper grpcObjectMapper = Mappers.getMapper(GrpcObjectMapper.class);

	@DisplayName("From serviceKonto")
	@Nested
	class TestFromServiceKonto {

		@Test
		void shouldMap() {
			var serviceKonto = fromServiceKonto();

			assertThat(serviceKonto).usingRecursiveComparison().isEqualTo(ServiceKontoTestFactory.create());
		}

		@Test
		void shouldCallGrpcObjectMapper() {
			fromServiceKonto();

			verify(grpcObjectMapper).mapFromGrpc(GrpcPostfachAddressTestFactory.createStringBasedIdentifier());
		}

		private ServiceKonto fromServiceKonto() {
			return mapper.fromServiceKonto(GrpcServiceKontoTestFactory.create());
		}
	}
}